@@ -18,6 +18,11 @@ bootdht_resample_data <- function(bootdat, our_resamples,
 
   # get all samples per stratum
   samps_per_strata <- unique(bf[, c(stratum_label, sample_label)])
+  # Check that the sampler names are unique across strata
+  # The number of unique sampler names should be the same as the rows in samps_per_strata
+  if(sample_label %in% our_resamples && !nrow(samps_per_strata) == length(unique(samps_per_strata[[sample_label]]))){
+    stop("Cannot bootstrap on samplers within strata as sampler ID values are not unique across strata. Please ensure all Sample.Label values are unique.", call. = FALSE)
+  }
   samps_per_strata <- by(bf[,c(stratum_label, sample_label)],
                          bf[[stratum_label]],
                          function(x) unique(x[[sample_label]]))
@@ -62,10 +67,19 @@ bootdht_resample_data <- function(bootdat, our_resamples,
 
   # concatenate list elements to data.frame
   rr <- do.call(rbind.data.frame, obs)
+  
+  # Check if there is a distance column otherwise look for distbegin
+  if("distance" %in% names(rr)){
+   dist_col <- "distance"
+  }else if("distbegin" %in% names(rr)){
+   dist_col <- "distbegin"
+  }else{
+   stop("No distance nor distbegin column in the bootstrap dataset.", call. = FALSE)
+  }
 
   # reset the object IDs to be unique (where there are observations)
-  rr[[obs_label]][is.na(rr[["distance"]])] <- NA
-  rr[[obs_label]][!is.na(rr[["distance"]])] <- 1:length(rr[[obs_label]][!is.na(rr[["distance"]])])
+  rr[[obs_label]][is.na(rr[[dist_col]])] <- NA
+  rr[[obs_label]][!is.na(rr[[dist_col]])] <- 1:length(rr[[obs_label]][!is.na(rr[[dist_col]])])
 
   return(rr)
 }
