@@ -23,12 +23,49 @@
 #'   * `Area` stratum area  (square nautical mile)
 #'   * `Sample.Label` transect identifier
 #'   * `Effort` transect length  (nautical mile)
+#'   * `object` unique object ID
 #'   * `distance` observed distance  (nautical mile)
 #'   * `Cluster.strat` strata based on cluster size: 1, 2 and 3+
 #'   * `size` cluster size
 #'   * `Study.Area` name of study area
 NULL
 
+#' Simulated minke whale data
+#'
+#' Data simulated from models fitted to 1992/1993 Southern Hemisphere minke
+#' whale data collected by the International Whaling Commission. See Branch and
+#' Butterworth (2001) for survey details (survey design is shown in figure
+#' 1(e)). Data simulated by David Borchers.
+#'
+#' Data are included here as both R data and as an Excel spreadsheet to
+#' illustrate the "flat file" input method. See [`flatfile`][flatfile] for how
+#' to load this data and an example analysis.
+#'
+#' @references Branch, T.A. and D.S. Butterworth (2001) Southern Hemisphere
+#' minke whales: standardised abundance estimates from the 1978/79 to 1997/98
+#' IDCR-SOWER surveys. Journal of Cetacean Research and Management 3(2):
+#' 143-174
+#'
+#' Hedley, S.L., and S.T. Buckland. Spatial Models for Line Transect Sampling.
+#' Journal of Agricultural, Biological, and Environmental Statistics 9, no. 2
+#' (2004): 181-199. \doi{10.1198/1085711043578}.
+#'
+#' @name minke
+#' @keywords datasets
+#' @source Shipped with the Distance for Windows.
+#' @docType data
+#' @format `data.frame` with 99 observations of 5 variables:
+#'   * `Region.Label` stratum label (`"North"` or `"South"`)
+#'   * `Area` stratum area
+#'   * `Sample.Label` transect identifier
+#'   * `Effort` transect length
+#'   * `distance` observed distance
+#'   * `object` unique object ID
+#' @examples
+#' data(minke)
+#' head(minke)
+NULL
+
 #' Cue counts of whale blows
 #'
 #' Cues are treated as an indirect count, requiring the use of multipliers.
@@ -514,6 +551,7 @@ NULL
 #'   this data set)
 #'   * `Effort`  temporal effort, i.e. the number of 2-second time-steps over
 #'   which the camera operated
+#'   * `object` unique object ID
 #'   * `distance`  radial distance (m) to interval midpoint
 #' @source Howe, E.J., Buckland, S.T., Després-Einspenner, M.-L. and Kühl, H.S.
 #' (2017), Distance sampling with camera traps. Methods Ecol Evol, 8:
